VisMetaABC
==========

.. currentmodule:: xrayvision.visibility

.. autoclass:: VisMetaABC
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~VisMetaABC.instrument
      ~VisMetaABC.observer_coordinate
      ~VisMetaABC.spectral_range
      ~VisMetaABC.time_range
      ~VisMetaABC.vis_labels

   .. rubric:: Attributes Documentation

   .. autoattribute:: instrument
   .. autoattribute:: observer_coordinate
   .. autoattribute:: spectral_range
   .. autoattribute:: time_range
   .. autoattribute:: vis_labels
